@@ -673,7 +673,7 @@ class Img(basicImg,AdvancedImg):
                 else:
                     self.img_new = frame[y + 5:y + h - 5, x + 5:x + w - 5]
 
-                self.img_new = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+                self.img_new = cv2.resize(self.img_new, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
                 cv2.imshow('result', self.img_new)
                 cv2.waitKey(3)
 
@@ -849,8 +849,7 @@ class Img(basicImg,AdvancedImg):
         if shape == 'circle':
             mask = self.mask_img
             # gaussian = cv2.GaussianBlur(mask, (3, 3), 0)
-            edge = cv2.Canny(mask, 30, 100, apertu
-                             =3)
+            edge = cv2.Canny(mask, 30, 100)
             self.circle_detect(edge)
         if shape in ['triangle', 'rectangle', 'polygon']:
             self.polygon_detect()
@@ -944,7 +943,7 @@ class Img(basicImg,AdvancedImg):
             self.mpDraw.draw_landmarks(img_new, handlms, self.mpHands.HAND_CONNECTIONS)
         else:
             self.fingertip = {}
-        img_new = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+        img_new = cv2.resize(img_new, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
         cv2.imshow('finger_detect', img_new)
 
     '''
@@ -1001,7 +1000,7 @@ class Img(basicImg,AdvancedImg):
             ('right_ankle', 28), ('left_shoulder', 11), ('right_shoulder', 12)):
                 self.body_menu[tur[0]] = (int(poselms[tur[1]].x * w), int(poselms[tur[1]].y * h))
             self.mpDraw.draw_landmarks(img_new, results.pose_landmarks, self.mp_pose.POSE_CONNECTIONS)
-        img_new = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+        img_new = cv2.resize(img_new, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
         cv2.imshow('body_detect', img_new)
 
     def wrist_mark(self, wrist:str='left_wrist', mark:str='x'):
@@ -1062,7 +1061,7 @@ class Img(basicImg,AdvancedImg):
         backGroundImage = cv2.resize(cv2.imread(backGroundImageSrc), (w, h), cv2.INTER_AREA)
 
         img_new = self.segmentor.removeBG(img_new, backGroundImage, threshold=0.5)
-        img_new = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+        img_new = cv2.resize(img_new, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
         cv2.imshow('backGroundChange', img_new)
 
     def faceMeshDetect_init(self):
@@ -1089,7 +1088,7 @@ class Img(basicImg,AdvancedImg):
             for faceLms in results.multi_face_landmarks:
                 self.mpDraw.draw_landmarks(img_new, faceLms, self.mpFaceMesh.FACEMESH_FACE_OVAL,
                                            landmark_drawing_spec=self.drawSpec)
-        img_new = cv2.resize(self.img, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
+        img_new = cv2.resize(img_new, dsize= (640,480) )  # 这一行是放大图像变回 640✖480
         cv2.imshow('faceMesh', img_new)
 
     def get_shape(self, parameter:str='width'):
