@@ -13,7 +13,6 @@ import time
 import pyaudio
 import audioop
 import pygame
-import websocket
 import requests
 import urllib
 import sys
@@ -29,11 +28,12 @@ system_platform = sys.platform
 main_path = '/home/pi/class/'
 if 'win' in system_platform:
     # 获取当前文件的位置
+
     file_path = os.path.join(os.getcwd().split('blockly-electron')[0],'blockly-electron')
     if not os.path.exists(file_path):
-        if os.path.join(os.getcwd(),"resources"):
+        if os.path.exists(os.path.join(os.getcwd(),"resources")):
             file_path = os.getcwd()
-    main_path = os.path.join(file_path + 'resources','assets','class').replace("\\","/")
+    main_path = os.path.join(file_path , 'resources','assets','class').replace("\\","/")
 # 文本文件夹
 txt_path = os.path.join(main_path , 'txt/').replace("\\","/")
 
@@ -323,7 +323,7 @@ class Yuyin():
                     r = requests.get(url)
                     result = r.content
                 except:
-                    raise BaseError('没有连接网络')
+                    raise FileNotFoundError('没有连接网络')
 
                 filename = str(filename)
                 file = audio_path + filename + '.mp3'
